==> haskell-regex-applicative-text-0.1.0.1-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-5p4ytsIcy0xGbXHAszJobL
key:                  regex-applicative-text-0.1.0.1-5p4ytsIcy0xGbXHAszJobL
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  f221a1cde67b513d05d27535a6a0b185
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/regex-applicative-text-0.1.0.1

hs-libraries:         HSregex-applicative-text-0.1.0.1-5p4ytsIcy0xGbXHAszJobL
depends:
    base-4.15.0.0 regex-applicative-0.3.4-Jy1njApdkQpCR4J1ED6gEz
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-FyFZQ2lSxOjAKQ7l7HzadI
key:                  regex-applicative-text-0.1.0.1-FyFZQ2lSxOjAKQ7l7HzadI
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  ef40459ea8b8a39efa3a26e5e1a2c97f
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/regex-applicative-text-0.1.0.1

hs-libraries:         HSregex-applicative-text-0.1.0.1-FyFZQ2lSxOjAKQ7l7HzadI
depends:
    base-4.15.0.0 regex-applicative-0.3.4-CnB87vJEwwFE5G1Uu7yJNp
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
